import { Component, h, Prop, Event, State } from '@stencil/core';
import { markdown } from 'markdown';
export class SFunboxCards {
    constructor() {
        /**
         * Стейт для переключения класса
         */
        this.toggleClassState = false;
    }
    render() {
        return (h("div", { class: this.cardContent.inStock ? 'enabled' : 'disabled', ref: el => (this.cardWrapperTag = el) },
            h("div", { class: "card", onMouseLeave: () => this.addClassForHoverEffect(), onClick: () => this.selectCard(this.cardContent.id) },
                h("div", { class: "card-text" },
                    h("h3", { class: "desc" }, this.cardContent.desc),
                    h("h3", { class: "question" }, this.cardContent.question),
                    h("h1", { class: "card-title" }, this.cardContent.title),
                    h("h2", { class: "menu" }, this.cardContent.menu),
                    h("div", { class: "amount", innerHTML: markdown.toHTML(this.cardContent.amount) }),
                    h("div", { class: "stock", innerHTML: markdown.toHTML(this.cardContent.stock) })),
                h("div", { class: "card-img", style: { backgroundImage: `url(${this.cardContent.img})` } }),
                h("div", { class: "weight-wrapper" },
                    h("span", { class: "amt" }, this.cardContent.weight),
                    h("span", { class: "weight" }, this.cardContent.kg))),
            h("div", { class: "info" }, this.toggleClassState ? (h("div", null, this.cardContent.selectedInfo)) : (h("div", null,
                this.cardContent.info,
                " ",
                h("a", { onClick: () => this.selectCard(this.cardContent.id) }, this.cardContent.link)))),
            h("div", { class: "not-available" }, this.cardContent.disabledInfo)));
    }
    /**
     * Переключает стейт и вызывает функцию для добавления класса
     * @param id
     */
    selectCard(id) {
        this.toggleClassState = !this.toggleClassState;
        this.addRemoveClass(id);
    }
    /**
     * Добавляет и удаляет класс selected
     * @param id
     */
    addRemoveClass(id) {
        if (id === this.cardContent.id && this.toggleClassState) {
            this.cardWrapperTag.classList.add('selected');
        }
        else {
            this.cardWrapperTag.classList.remove('selected');
        }
        this.cardWrapperTag.addEventListener('mouseleave', () => {
            this.cardWrapperTag.classList.add('selected-card');
        });
    }
    /**
     * Состояние наведения применяется к выбранной упаковке не сразу, а после
     того, как курсор ушел с нее после первоначального выбора.
     */
    addClassForHoverEffect() {
        this.cardWrapperTag.classList.add('selected-hover');
    }
    static get is() { return "s-funbox-cards"; }
    static get encapsulation() { return "scoped"; }
    static get originalStyleUrls() { return {
        "$": ["s-funbox-cards.css"]
    }; }
    static get styleUrls() { return {
        "$": ["s-funbox-cards.css"]
    }; }
    static get properties() { return {
        "cardContent": {
            "type": "any",
            "mutable": false,
            "complexType": {
                "original": "any",
                "resolved": "any",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "\u0414\u0430\u043D\u043D\u044B\u0435 \u0434\u043B\u044F \u043A\u0430\u0440\u0442\u043E\u0447\u043A\u0438"
            },
            "attribute": "card-content",
            "reflect": false
        }
    }; }
    static get states() { return {
        "toggleClassState": {}
    }; }
    static get events() { return [{
            "method": "clickOnCard",
            "name": "clickOnCard",
            "bubbles": true,
            "cancelable": true,
            "composed": true,
            "docs": {
                "tags": [],
                "text": "\u041A\u043B\u0438\u043A \u043F\u043E \u043A\u0430\u0440\u0442\u043E\u0447\u043A\u0435"
            },
            "complexType": {
                "original": "any",
                "resolved": "any",
                "references": {}
            }
        }]; }
}
